VideosdkMediaEffects class

Constructors

VideosdkMediaEffects()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

applyVirtualBackground({required Uri backgroundSource}) Future<void>
changeVirtualBackground({required Uri backgroundSource}) Future<void>
removeVirtualBackground() Future<void>
startNoiseSuppression() Future<void>
Enables native noise suppression on the WebRTC audio thread.
stopNoiseSuppression() Future<void>
Disables native noise suppression.

Constants

methodChannel → const MethodChannel